#!/bin/sh
#
# Compute Phase Cross Correlation of noise data.
# Script finds all possible station combinations.
#
# File structure: YYYY.JJJ/traces.sac
#  YYYY.JJJ  : year j-day (e.g., 2019.001, 2019.002, ...)
#  traces.sac: traces for all available stations and 
#              corresponding date. E.g., 
#              2019.001.00.00.STA1.HHZ.sac
#              2019.001.00.00.STA2.HHZ.sac
#              2019.001.00.00.STA3.HHZ.sac
#              2019.001.02.00.STA1.HHZ.sac
#              2019.001.02.00.STA2.HHZ.sac
#              2019.001.02.00.STA3.HHZ.sac
#              ...
#              2019.001.22.00.STA3.HHZ.sac
#    
# See 1_README_example_pcc for further information.
#
# 25/07/2019, schimmel@ictja.csic.es
#--------------------------------------

# Executables:
#-------------
pcc="../../pcc5iMP"

# Frequency band pass:
#---------------------
bp1=1.0 
bp2=3.0

# Working dir:
#-------------
dir0=`pwd`

# Loop over all data:
#--------------------
for i in 2018.???
do
dir=$dir0"/"$i
cd $dir

# Pre-processing:
#----------------
# BP:
sac << END
r 20*HZ.sac
rmean
rtrend
bp co $bp1 $bp2 p 2
w append bp
quit
END

ls -1 20*HZ.sac | awk '{print substr($1,1,15)}' | uniq > tmpo

# While-loop over different hours
#--------------------------------
while read line;
do

# Correlation loops:
#-------------------
n1=`ls -1 $line*HZ*bp | wc -l | awk '{ print $1}'`
# start n1 while-loop 
while [ "$n1" -ge "1" ]
do

f1=` ls -1 $line*HZ*bp | tail -$n1 | head -1 ` 
n2=` echo $n1 | awk '{ print $1-1}' ` 

#start n2 while-loop:
while [ "$n2" -ge "1" ]
do

f2=` ls -1 $line*HZ*bp | tail -$n2 | head -1 ` 

sac <<- %
r $f1 $f2
sync
w d1.sac d2.sac
rh d1.sac d2.sac
setbb a &1,b
setbb b &2,b
setbb c &1,e
setbb d &2,e
cut ( (max %a %b%) + 1 ) ( (min %c %d%) - 1 )
r d1.sac d2.sac
write over
quit
%

sta1=`echo $f1 | awk '{ print substr($1,20,4)}' `
sta2=`echo $f2 | awk '{ print substr($1,20,4)}' `
dat=`echo $f1 | awk '{ print substr($1,1,15)}' `
paar="$sta1"Z_"$sta2"Z
paar0=../"$paar"
mkdir -p $paar0

# cross-correlate data without time freq - normalization (PCC):
#===============================================================
par=" isac osac tl1=-30 tl2=30 nn nsmin=45000 pov=2 "
echo PCC:  $paar0"/"$dat"pcc2_"$paar".sac" $par
$pcc d1.sac d2.sac $par pcc=$paar0"/"$dat"pcc2_"$paar

n2=`echo $n2 | awk '{ print $1-1}' ` 
#end n2 while-loop
done

n1=`echo $n1 | awk '{ print $1-1}' `
#end n1 while-loop
done 

# End while-loop over hours
done < tmpo

# clean up 
\rm -f *sacbp*
\rm -f d?.sac tmpo

# end data for-loop over i:
done

exit
